/**
 *
 *	<b>InteractiveIO.java</b><br>
 *	
 *	The class models console input and output. A BufferedReader object 
 *	is set up to get input from the keyboard. System.out.println is used 
 *	to send information to the monitor
 *	
 *	@author		D. Slater
 *	@date		September 6, 2001
 *	@version: 	0.8
 *
 */



import java.io.*;

public class InteractiveIO {
	
		/**
		 *	instance variables
		 */
		
	BufferedReader br;

		/**
		 *	 sets up the Buffered Reader object to handle keyboard input
		 */
		
	public InteractiveIO() {
	
		br = new BufferedReader(new InputStreamReader(System.in));
	}
	
		/**
		 *	write str to the monitor
		 *	
		 *	@param String str	the string to be displayed
		 */
			
	public void write(String str) {
	
		System.out.print(str);	
	}
	
		/**
		 *	write empty string to the monitor with an end of line character at 
		 *	the end
		 */
	public void writeln() {
	
		System.out.println();	
	}
	
		/**
		 *	write str to the monitor with an endl of line at the end
		 *
		 *	@param String str	the string to be displayed
		 */
		
	public void writeln(String str) {
	
		System.out.println(str);	
	}
	
		/**
		 *	write obj using toString() method to the monitor 
		 *	with an end of line at the end
		 *	
		 *	@param Object obj	the object to be displayed
		 */
		
	public void writeln(Object obj) {
	
		System.out.println(obj.toString());	
	}
	
		/**
		 *	write obj using toString() method to the monitor 
		 *	without an end of line at the end
		 *
		 *	@param Object obj	the object to be displayed
		 */
		
	public void write(Object obj) {
	
		System.out.println(obj.toString());	
	}
	


		/**
		 *	write str to the monitor. read and return a String from the 
		 *	keyboard using instance variable br	
		 *	
		 *	@param String str	the string to be displayed
		 *	@return String		input from keyboard or null
		 */
		
	public String promptAndRead(String str) throws Exception {
	
		write(str);
		String in = br.readLine();
		if (in == null) {
			return null;
		}
		return in;
	}
	
}